@@ -5,8 +5,8 @@ from typing import Text
 
 import torchaudio
 
-from ruth_tts_transformer.ruth_tts.api import TextToSpeech
-from ruth_tts_transformer.ruth_tts.utils.audio import load_voice
+from ruth_tts_transformer.parser import TextToSpeech
+from ruth_tts_transformer.utils.audio import load_voice
 
 
 class TTS:
